<?php
class Settings {
/* Main configuration part */

	/**
	* Set the name of the dreambox. Anything is allowed :P
	* This setting is optional
	* @access private
	* @var string
	*/
	private static $dreamboxName = "Yoshie's Dreambox";

	/**
	* Set the local IP address of your dreambox. Should be an internal IP number or hostname. For best performance, use an IP number.
	* This setting is required
	* @access private
	* @var string
	*/
	private static $dreamboxIP = "192.168.5.119";
	
	/**
	* Set the web port number of your dreambox. Mostly is should be port 80, but some versions have a different portnumber.
	* This setting is required
	* @access private
	* @var int
	*/
	private static $dreamboxWebPort = 80;

	/**
	* Set the username for the dreambox webinterface. Leave empty when no authentication is required.
	* This setting is optional
	* @access private
	* @var string
	*/
	private static $dreamboxUserName = "";

	/**
	* Set the password for the dreambox webinterface. Leave empty when no authentication is required.
	* This setting is optional
	* @access private
	* @var string
	*/
	private static $dreamboxPassword = "";

	/**
	* Set the enigma version of the dreambox. Valid values are enigma1 of enigma2
	* This setting is required
	* @access private
	* @var string
	*/
	private static $dreamboxEnigmaVersion = "enigma2";
	
	/**
	* Set the the program name. Should not be changed in respect to the programmer :)
	* This setting is required
	* @access private
	* @var string
	*/
	private static $lProgramName = "Dreambox ReStream";
	
	/**
	* Set the program version. Should not be changed
	* This setting is required
	* @access private
	* @var string
	*/
	private static $lVersion = "2.0";

	/**
	* The full path to your movies folder on the server. It has to be a local path. 
	*
	* Leave empty to disable this feature.
	* This setting is optional
	*
	* @access private
	* @var string
	*/
	//private static $lMoviesPath = "/media/film/";
	private static $lMoviesPath = "";

	/**
	* Set the alowed extension for valid movies. Should not be changed
	* This setting is required
	* @access private
	* @var string
	*/
	private static $lValidMovies = "avi,mkv,mpeg,mpg,mp4";
	
/* Private configuration */

	/**
	* If you want to make Dreambox Restream private, set the variable below to 1 and set the username and password
	* Set to false to make Dreambox Restream plublic
	* This setting is optional
	*/
	private static $lPivateModus = false;
	
	private static $lPrivateModusUsername = "dreambox";
	
	private static $lPrivateModusPassword = "dreambox";

/* VLC configuration */

	/**
	* Set the location of the VLC server executable. At least set the value that is corresponding with your 
	* operating system where the PHP code is running. The default settings should be working for 90% of the time.
	* This setting is required
	* @access private
	* @var string
	*/
	private static $lVLCLocationLinux 	= "/usr/bin/vlc";
	private static $lVLCLocationWindows = "C:/Progra~1/VideoLAN/VLC/vlc.exe";
	private static $lVLCLocationMacOSX 	= "/Applications/VLC.app/Contents/MacOS/VLC";
	
	/**
	* Set the external IP or hostname for external connections to the VLC Server
	* This setting is required
	* @access private
	* @var string
	*/
	private static $vlcIP = "127.0.0.1";

	/**
	* Set the the internal port number for streaming.
	* This setting is required
	* @access private
	* @var string
	*/
	private static $vlcLanStreamPort = "8668";
	
	private static $lMultiBitRate = true;

/* Wowza configuration */

	/**
	* Set the external IP or hostname for external connections to the Wowza Media Server
	*
	* Leave empty to disable the use of Wowza Media Server and use the VLC build in server. But that is less stable
	* This setting is optional
	*
	* Download free developer version of wowza at: http://wowzamedia.com/store.html
	* @access private
	* @var string
	*/
	private static $wowzaServerName = "wowza.theyosh.nl";
	//private static $wowzaServerName = "";
	
	/**
	* Set to false if you have a full licensed version of Wowza Media Server 2. 
	* This will enable iPhone streaming with chunks and Smooth streaming to Silverlight clients
	*/
	private static $wowzaServerDeveloperLicense = true;

/* MediaInfo configration */

	/**
	* Set the location of the MediaInfo server executable. At least set the value that is corresponding with your 
	* operating system where the PHP code is running. The default settings should be working for 90% of the time.
	*
	* Leave empty to disable the support of MediaInfo. You will lose the duration information on your movies.
	* This setting is optional
	*
	* @access private
	* @var string
	*/
	private static $lMediaInfoLocationLinux = "/usr/bin/mediainfo";
	private static $lMediaInfoLocationMacOSX = "C:/Progra~1/MediaInfo/mediainfo.exe";
	private static $lMediaInfoLocationWindows = "/Applications/MediaInfo.app/Contents/MacOS/MediaInfo";

/* Other configuration */

	/**
	* Set the location of the ggrab server executable. This can help to improve the stablity of the stream.
	*
	* Leave empty to disable the support of ggrab. (Default)
	* This setting is optional
	*
	* @access private
	* @var string
	*/
	private static $lGrabLocationWindows = "";
	//private static $lGgrabLocationWindows = "C:/ggrab/ggrab.exe";
	
	
/* End of settings configuration. You should not edit below this line */

	/**
	* Get the next program from the program guide.
	* @return string
	*/
	static public function getDreamboxName() {
		return trim(Settings::$dreamboxName);
	}
	
	/**
	* Get the program name.
	* @return string
	*/
	static public function getProgramName() {
		return trim(Settings::$lProgramName);
	}

	/**
	* Get the program version number.
	* @return string
	*/
	static public function getVersionNumber() {
		return trim(Settings::$lVersion);
	}

	/**
	* Get the IP number of the dreambox.
	* @return string
	*/
	static public function getDreamboxIP() {
		return gethostbyname(trim(Settings::$dreamboxIP));
	}
	
	static public function getDreamboxWebPort() {
		return gethostbyname(trim(Settings::$dreamboxWebPort));
	}

	/**
	* Get the username of the dreambox.
	* @return string
	*/
	static public function getDreamboxUserName() {
		return trim(Settings::$dreamboxUserName);
	}

	/**
	* Get the password of the dreambox.
	* @return string
	*/
	static public function getDreamboxPassword() {
		return trim(Settings::$dreamboxPassword);
	}

	/**
	* Get the enigma version of the dreambox.
	* @return string
	*/
	static public function getEnigmaVersion() {
		return trim(Settings::$dreamboxEnigmaVersion);
	}

	/**
	* Return the VLC executable based on OS type.
	* @return string
	*/
	static public function getVLCExecutable() {
		$lVLCExecutable = "";
		if (Utils::isWindows()) {
			$lVLCExecutable = trim(Settings::$lVLCLocationWindows);
		} elseif (Utils::isMacOSX()) {
			$lVLCExecutable = trim(Settings::$lVLCLocationMacOSX);
		} elseif (Utils::isLinux()) {
			$lVLCExecutable = trim(Settings::$lVLCLocationLinux);
		}
		return ($lVLCExecutable != "" && file_exists($lVLCExecutable)? $lVLCExecutable : false);
	}

	/**
	* Get the VLC Server internal IP number.
	* @return string
	*/
	static public function getVLCIP() {
		return trim(gethostbyname(Settings::$vlcIP));
	}

	/**
	* Get the internal streaming port of the VLC Server.
	* @return string
	*/
	static public function getVLCPort() {
		return trim(Settings::$vlcLanStreamPort);
	}
	
	static public function isMultiBitRate() {
		return (Settings::$lMultiBitRate === true);
	}
	
	
	/**
	* Check if Wowza is supported. Returns true when Wowza is enabled, and therefore show a rtmp transport option that uses Wowza
	* @return boolean
	*/
	static public function isWowzaEnabled() {
		return (trim(Settings::$wowzaServerName) != "");
	}
	
	/**
	* Get the wowza server name.
	* @return string
	*/
	static public function getWowzaServerName() {
		return trim(Settings::$wowzaServerName);
	}
	
	static public function isFullWowzaServer() {
		return (Settings::$wowzaServerDeveloperLicense === false);
	}
	
	static public function getMediaInfoxecutable() {
		$lMediaInfoExecutable = "";
		if (Utils::isWindows()) {
			$lMediaInfoExecutable = trim(Settings::$lMediaInfoLocationWindows);
		} elseif (Utils::isMacOSX()) {
			$lMediaInfoExecutable = trim(Settings::$lMediaInfoLocationMacOSX);
		} elseif (Utils::isLinux()) {
			$lMediaInfoExecutable = trim(Settings::$lMediaInfoLocationLinux);
		}
		return ($lMediaInfoExecutable != "" && file_exists($lMediaInfoExecutable)? $lMediaInfoExecutable : false);
	}

	/**
	* Returns the location of ggrab program. When empty, ggrab is disabled.
	* @return string
	*/
	static public function getGgrabLocation() {
		return (Settings::$lGrabLocationWindows != "" && file_exists(Settings::$lGrabLocationWindows)? Settings::$lGrabLocationWindows : false);
	}

	static public function isPrivate() {
		return (Settings::$lPivateModus === true && Settings::getPrivateModusUsername() != "" && Settings::getPrivateModusPassword() != "");
	}

	static public function getPrivateModusUsername() {
		return trim(Settings::$lPrivateModusUsername);
	}

	static public function getPrivateModusPassword() {
		return trim(Settings::$lPrivateModusPassword);
	}

	static public function getMoviesPath() {
		return trim(Settings::$lMoviesPath);
	}

	static public function getValidMovies() {
		return explode(",",Settings::$lValidMovies);
	}
	
	public function getDebug() {
		return (isset($_GET["debug"]) && $_GET["debug"] == 1);
	}
}
?>
